<?php
/**
 * Theme Activation.
 *
 * @package Overflow
 */

if ( ! class_exists( 'CSCO_Theme_Activation' ) ) {

	/**
	 * This class to activate your theme and open up new opportunities.
	 */
	class CSCO_Theme_Activation {

		/**
		 * The purchase code.
		 *
		 * @var string $purchase_code The purchase code.
		 */
		public $purchase_code = null;

		/**
		 * The email address.
		 *
		 * @var string $email The email address.
		 */
		public $email = null;

		/**
		 * The message.
		 *
		 * @var string $msg The message.
		 */
		public $msg;

		/**
		 * Constructor.
		 */
		public function __construct() {
			$this->trigger_license();

			add_action( 'admin_menu', array( $this, 'register_options_page' ) );
			add_action( 'admin_enqueue_scripts', array( $this, 'enqueue_scripts' ) );
			add_action( 'admin_footer', array( $this, 'display_theme_notice' ) );
			add_action( 'admin_notices', array( $this, 'display_license_notice' ) );
			add_action( 'wp_ajax_csco_dismissed_handler', array( $this, 'dismissed_handler' ) );
		}

		/**
		 * Register admin page
		 *
		 * @since 1.0.0
		 */
		public function register_options_page() {
			add_theme_page( esc_html__( 'Theme License', 'overflow' ), esc_html__( 'Theme License', 'overflow' ), 'manage_options', 'csco-activation', array( $this, 'settings_page' ) );
		}

		/**
		 * Build admin page
		 */
		public function settings_page() {

			wp_verify_nonce( null );

			if ( ! current_user_can( 'manage_options' ) ) {
				wp_die( esc_html__( 'You do not have sufficient rights to view this page.', 'overflow' ) );
			}
			?>
				<div class="wrap">
					<h1><?php esc_html_e( 'Theme License', 'overflow' ); ?></h1>

					<?php
					// Message output.
					if ( $this->msg ) {
						echo wp_kses( $this->msg, 'post' );
					}

					// Get template name.
					$slug = get_template();

					// Get code from DB.
					if ( ! $this->purchase_code ) {
						$this->purchase_code = get_option( 'envato_purchase_code_' . csco_get_license_data( 'item_id' ) );
					}

					// Get email from DB.
					if ( ! $this->email ) {
						$this->email = get_option( $slug . '_email' );
					}

					if ( ! $this->email ) {
						$this->email = get_bloginfo( 'admin_email' );
					}

					// Get current status.
					$status = csco_get_license_data( 'status' );
					?>
					<div id="poststuff">

						<div class="postbox">

							<h2 class="hndle">
								<span>
									<?php if ( $status ) { ?>
										<?php esc_html_e( 'License Information', 'overflow' ); ?>
									<?php } else { ?>
										<?php esc_html_e( 'License Activation', 'overflow' ); ?>
									<?php } ?>
								</span>
							</h2>

							<div class="inside">
								<br><p class="description <?php echo esc_attr( $status ? 'hidden' : '' ); ?>"><?php esc_html_e( 'To unlock all theme features, please enter your purchase code below. If you don’t have a purchase code, please purchase the theme on', 'overflow' ); ?> <a target="_blank" href="https://themeforest.net/user/codesupplyco/portfolio?ref=codesupplyco"><?php esc_html_e( 'ThemeForest', 'overflow' ); ?></a>.</p>

								<!-- Active Websites -->
								<?php if ( $status ) { ?>
									<form method="post">
										<?php wp_nonce_field(); ?>

										<table class="form-table">
											<tr>
												<th scope="row"><?php esc_html_e( 'Active Websites', 'overflow' ); ?></label></th>
												<td>
													<?php
													$history = csco_get_license_data( 'license_history' );

													if ( $history ) {
														?>
														<?php
														foreach ( $history as $item ) {
															if ( 'active' === $item['status'] ) {
																echo sprintf( '<p><a target="_blank" href="%1$s">%1$s</a></p>', esc_url( $item['domain'] ) );
															}
														}
														?>
														<br>
														<p>
															<input type="hidden" name="code" value="<?php echo esc_attr( $this->purchase_code ); ?>">

															<button class="button" type="submit" name="action" value="check"><?php esc_html_e( 'Check Again', 'overflow' ); ?></button>
														</p>
														<?php
													} elseif ( 'dev' === csco_get_license_data( 'item_id' ) ) {
														esc_html_e( 'Development Mode', 'overflow' );
													}
													?>
												</td>
											</tr>
										</table>
									</form>
								<?php } ?>

								<!-- Information -->
								<form method="post">
									<?php wp_nonce_field(); ?>

									<table class="form-table">
										<!-- Purchase Code -->
										<tr class="<?php echo esc_attr( $status ? 'hidden' : '' ); ?>">
											<th scope="row"><?php esc_html_e( 'Purchase Code', 'overflow' ); ?></label></th>
											<td>
												<input class="regular-text" type="text" name="code" value="<?php echo esc_attr( $this->purchase_code ); ?>">
											</td>
										</tr>
										<!-- Email Address -->
										<tr class="<?php echo esc_attr( $status ? 'hidden' : '' ); ?>">
											<th scope="row"><?php esc_html_e( 'Email Address', 'overflow' ); ?></label></th>
											<td>
												<input class="regular-text" type="text" name="email" value="<?php echo esc_attr( $this->email ); ?>">
												<p class="description"><?php esc_html_e( 'This address is used for license activation purposes only.', 'overflow' ); ?></p>
											</td>
										</tr>
										<!-- Updates -->
										<tr class="<?php echo esc_attr( $status ? 'hidden' : '' ); ?>">
											<th scope="row"><?php esc_html_e( 'Updates', 'overflow' ); ?></label></th>
											<td>
											<label><input name="newsletter" type="checkbox" value="1" <?php checked( (bool) get_option( $slug . '_license_newsletter', true ) ); ?>> <?php esc_html_e( 'Get notified of promotions and important updates', 'overflow' ); ?></label>
											<p class="description"><?php esc_html_e( 'We set a special price for all new themes for just a few days. Get notified of all introductory, flash and seasonal sales by signing up to our updates.', 'overflow' ); ?></p>
											</td>
										</tr>
										<!-- Purchase Date -->
										<tr class="<?php echo esc_attr( ! $status ? 'hidden' : '' ); ?>">
											<th scope="row"><?php esc_html_e( 'Purchase Date', 'overflow' ); ?></label></th>
											<td>
												<?php $sold_at = csco_get_license_data( 'sold_at' ); ?>

												<?php echo esc_html( date( 'F d, Y', strtotime( $sold_at ) ) ); ?>
											</td>
										</tr>
										<!-- Supported Until -->
										<?php
										$supported_until = csco_get_license_data( 'supported_until' );

										if ( strtotime( $supported_until ) < strtotime( 'now' ) ) {
										?>
											<tr class="<?php echo esc_attr( ! $status ? 'hidden' : '' ); ?>">
												<th scope="row"><?php esc_html_e( 'Supported Until', 'overflow' ); ?></label></th>
												<td>
													<span style="color:red">
														<?php echo esc_html( date( 'F d, Y', strtotime( $supported_until ) ) ); ?>

														<?php esc_html_e( ' (Expired)', 'overflow' ); ?>
													</span>
													<p class="description"><?php esc_html_e( 'Please renew your item support for any support requests. See', 'overflow' ); ?> <a href="https://help.market.envato.com/hc/en-us/articles/207886473-Extending-and-Renewing-Item-Support" target="_blank"><?php esc_html_e( 'this document', 'overflow' ); ?></a> <?php esc_html_e( 'for more details.', 'overflow' ); ?></p>
												</td>
											</tr>
										<?php } ?>
										<!-- Submitbox -->
										<tr>
											<th scope="row">
												<?php
												if ( $status ) {
													esc_html_e( 'Deactivation', 'overflow' );
												}
												?>
											</th>
											<td>
												<?php if ( $status ) { ?>
													<button name="action" value="deactivate" type="submit" class="button button-primary button-large" id="publish"><?php esc_html_e( 'Deactivate License', 'overflow' ); ?></button>
												<?php } ?>

												<?php if ( ! $status ) { ?>
													<button name="action" value="activate" type="submit" class="button button-primary button-large" id="publish"><?php esc_html_e( 'Activate License', 'overflow' ); ?></button>
												<?php } ?>
											</td>
										</tr>
									</table>
								</form>
							</div>
						</div>
					</div>
				</div>
			<?php
		}

		/**
		 * Trigger license.
		 */
		public function trigger_license() {
			if ( ! isset( $_POST['_wpnonce'] ) || ! wp_verify_nonce( $_POST['_wpnonce'] ) ) { // Input var ok; sanitization ok.
				return;
			}

			// Get template name.
			$slug = get_template();

			// Get action.
			if ( isset( $_POST['action'] ) ) { // Input var ok.
				$action = sanitize_text_field( wp_unslash( $_POST['action'] ) ); // Input var ok.
			}

			// Get purchase code.
			if ( isset( $_POST['code'] ) && $_POST['code'] ) { // Input var ok; sanitization ok.
				$this->purchase_code = sanitize_text_field( wp_unslash( $_POST['code'] ) ); // Input var ok.
			}

			// Check exists code.
			if ( ! $this->purchase_code ) {
				$this->msg = $this->set_message( esc_html__( 'Purchase code not entered.', 'overflow' ) );
				return;
			}

			if ( 'activate' === $action || 'deactivate' === $action ) {
				// Get newsletter.
				if ( isset( $_POST['newsletter'] ) ) { // Input var ok.
					update_option( $slug . '_license_newsletter', true );

					$newsletter = esc_html__( 'yes', 'overflow' );
				} else {
					update_option( $slug . '_license_newsletter', false );

					$newsletter = esc_html__( 'no', 'overflow' );
				}

				// Get email.
				if ( isset( $_POST['email'] ) ) { // Input var ok.
					$this->email = sanitize_text_field( wp_unslash( $_POST['email'] ) ); // Input var ok.

					update_option( $slug . '_email', $this->email );
				}
			}

			// Set url for query.
			$theme_data = wp_get_theme( get_template() );

			$url = sprintf( '%s/wp-json/csco/v1/check-license', $theme_data->get( 'AuthorURI' ) );

			// Remote query.
			$response = wp_remote_post( $url, array(
				'timeout'     => 45,
				'redirection' => 5,
				'httpversion' => '1.0',
				'blocking'    => true,
				'headers'     => array(),
				'body'        => 'check' === $action ? array(
					'code'       => $this->purchase_code,
					'theme_name' => $theme_data->get( 'Name' ),
					'action'     => $action,
				) : array(
					'code'       => $this->purchase_code,
					'email'      => $this->email,
					'domain'     => is_multisite() ? network_site_url() : site_url(),
					'theme_name' => $theme_data->get( 'Name' ),
					'newsletter' => $newsletter,
					'action'     => $action,
				),
				'cookies'     => array(),
			) );

			if ( is_wp_error( $response ) ) {
				$this->msg = $this->set_message( esc_html__( 'No connection to the server, try another time, or contact support.', 'overflow' ) );
				return;
			}

			// Retrieve data.
			$data = wp_remote_retrieve_body( $response );

			// JSON Decode.
			$data = json_decode( $data, true );

			if ( isset( $data['data'] ) ) {
				$data = $data['data'];
			}

			// Update license.
			if ( isset( $data['item_id'] ) && ( 'activate' === $action || 'check' === $action ) ) {
				// Reset notices.
				delete_transient( sprintf( '%s_license_expired', $slug ) );
				delete_transient( sprintf( '%s_license_limit', $slug ) );

				// Update purchase code.
				update_option( 'envato_purchase_code_' . $data['item_id'], $this->purchase_code );

				// Update license data.
				update_option( $slug . '_license_data', $data );
			}

			// Delete license.
			if ( isset( $data['item_id'] ) && 'deactivate' === $action ) {
				$this->purchase_code = null;
				// Delete purchase code.
				delete_option( 'envato_purchase_code_' . $data['item_id'] );
				// Delete license data.
				delete_option( $slug . '_license_data' );
			}

			// Output message.
			if ( ! isset( $data['message'] ) ) {
				$this->msg = $this->set_message( esc_html__( 'Could not receive data from the server, try another time, or contact support.', 'overflow' ) );
			} else {
				$this->msg = $data['message'];
			}
		}

		/**
		 * Check if there is an update in the current theme.
		 */
		public function has_theme_update() {
			// Get data updates.
			$updates = array();
			if ( current_user_can( 'update_themes' ) ) {
				$updates_transient = get_site_transient( 'update_themes' );
				if ( isset( $updates_transient->response ) ) {
					$updates = $updates_transient->response;
				}
			}

			// Get theme slug.
			$slug = get_template();

			if ( isset( $updates[ $slug ] ) && ! empty( $updates[ $slug ]['package'] ) ) {
				return true;
			}
		}

		/**
		 * Set message.
		 *
		 * @param string $text The text of message.
		 * @param string $type The type of message.
		 */
		public function set_message( $text, $type = 'error' ) {
			ob_start();
			?>
			<div class="notice notice-<?php echo esc_attr( $type ); ?>">
				<p><?php echo wp_kses( $text, 'post' ); ?></p>
			</div>
			<?php
			return ob_get_clean();
		}

		/**
		 * Display a notification on the themes page.
		 */
		public function display_theme_notice() {
			global $pagenow;

			if ( $this->has_theme_update() ) {
				return false;
			}

			if ( csco_get_license_data( 'status' ) ) {
				return false;
			}

			// If current page is themes.
			if ( 'themes.php' === $pagenow ) {
				// Notice.
				ob_start();
				?>
				<div class="notice inline notice-warning notice-alt">
					<p>
						<?php esc_html_e( 'Please verify purchase to get advanced features.', 'overflow' ); ?>
						<a class="button-link" href="<?php echo esc_url( admin_url( 'themes.php?page=csco-activation' ) ); ?>"><?php echo esc_html__( 'Verify now', 'overflow' ); ?></a>
					</p>
				</div>
				<?php
				$msg = str_replace( PHP_EOL, '', ob_get_clean() );

				// Get theme slug.
				$slug = get_template();
				?>
				<script>
					jQuery(document).ready(function($) {
						setTimeout( () => {
							$( '#<?php echo esc_attr( $slug ); ?>-action' ).before( '<?php echo wp_kses( $msg, 'post' ); ?>' );
						}, 10 );
					});
				</script>
				<?php
			}
		}

		/**
		 * Display a notification of license.
		 */
		public function display_license_notice() {
			$screen = get_current_screen();

			if ( ! csco_get_license_data( 'status' ) ) {
				return;
			}

			// Get theme slug.
			$slug = get_template();

			// Dismissible.
			$dismissible = null;

			if ( 'appearance_page_csco-activation' !== $screen->base ) {
				$dismissible = 'is-dismissible';
			}

			/*
			 * Support expired.
			 */

			// Get license data.
			$supported_until = csco_get_license_data( 'supported_until' );

			// Date comparison.
			if ( strtotime( $supported_until ) < strtotime( 'now' ) ) {
				// Set transient name.
				$transient_name = sprintf( '%s_license_expired', $slug );

				if ( ( ! get_transient( $transient_name ) && $dismissible ) || ! $dismissible ) {
					?>
					<div class="csco-notice notice notice-warning <?php echo esc_attr( $dismissible ); ?>" data-notice="<?php echo esc_attr( $transient_name ); ?>">
						<p><strong><?php esc_html_e( 'Support expired.', 'overflow' ); ?></strong>
						<?php
							// Translators: theme name and link activation.
							echo wp_kses( sprintf( __( 'Your support for the %1$s theme has expired. Please %2$s for any support requests.', 'overflow' ), csco_get_theme_data( 'Name' ), '<a href="' . admin_url( '/themes.php?page=csco-activation' ) . '">' . __( 'renew your support license', 'overflow' ) . '</a>' ), 'post' );
						?>
						</p>
					</div>
					<?php
				}
			}

			/*
			 * Multiple active websites detected.
			 */

			// Get license history.
			$history = (array) csco_get_license_data( 'license_history' );
			$count   = (int) csco_get_license_data( 'purchase_count' );

			$actived = array_filter( $history, function( $item ) {
				return isset( $item['status'] ) && 'active' === $item['status'];
			} );

			// Check the number of purchases.
			if ( count( $actived ) > $count ) {
				// Set transient name.
				$transient_name = sprintf( '%s_license_limit', $slug );

				if ( ( ! get_transient( $transient_name ) && $dismissible ) || ! $dismissible ) {
				?>
					<div class="csco-notice notice notice-warning <?php echo esc_attr( $dismissible ); ?>" data-notice="<?php echo esc_attr( $transient_name ); ?>">
						<p><strong><?php esc_html_e( 'Multiple active websites detected.', 'overflow' ); ?></strong> <?php esc_html_e( 'Looks like you’re using the same theme license on multiple websites. A website theme can only be customized to create one customized website according to the ThemeForest license terms. If you want to create a second website from the same theme, you’ll need to', 'overflow' ); ?> <a href="<?php esc_url( admin_url( '/themes.php?page=csco-activation' ) ); ?>"><?php esc_html_e( 'purchase another license', 'overflow' ); ?></a>.</p>
					</div>
				<?php
				}
			}
		}

		/**
		 * Dismissed handler
		 */
		public function dismissed_handler() {
			wp_verify_nonce( null );

			if ( isset( $_POST['notice'] ) ) { // Input var ok; sanitization ok.
				set_transient( sanitize_text_field( wp_unslash( $_POST['notice'] ) ), true, 90 * DAY_IN_SECONDS ); // Input var ok.
			}
		}

		/**
		 *  Enqunue Scripts
		 *
		 * @param string $page Current page.
		 */
		public function enqueue_scripts( $page ) {

			ob_start();
			?>
			<script>
				jQuery(function($) {
					$( document ).on( 'click', '.csco-notice .notice-dismiss', function () {
						jQuery.post( 'ajax_url', {
							action: 'csco_dismissed_handler',
							notice: $( this ).closest( '.csco-notice' ).data( 'notice' ),
						});
					} );
				});
			</script>
			<?php
			$script = str_replace( 'ajax_url', admin_url( 'admin-ajax.php' ), ob_get_clean() );

			wp_add_inline_script( 'jquery-core', str_replace( array( '<script>', '</script>' ), '', $script ) );
		}
	}

	/**
	 * Display the license notification.
	 */
	function csco_license_notice() {
		if ( ! csco_get_license_data( 'status' ) ) {
		?>
		<div class="notice inline notice-warning notice-alt">
			<p><strong><?php esc_html_e( 'Thank you for choosing our theme. To take advantage of all features please verify purchase theme.', 'overflow' ); ?></strong>
			<a href="<?php echo esc_url( admin_url( 'themes.php?page=csco-activation' ) ); ?>"><?php echo esc_html__( 'Verify now', 'overflow' ); ?></a></p>
		</div>
		<?php
		}
	}

	/**
	 * Get data of license.
	 *
	 * @param string $param The name param.
	 */
	function csco_get_license_data( $param ) {
		// Get theme slug.
		$slug = get_template();

		$data = get_option( sprintf( '%s_license_data', $slug ), array() );

		if ( is_array( $data ) && isset( $data[ $param ] ) ) {
			return $data[ $param ];
		}
	}

	new CSCO_Theme_Activation();
}
